@@ -1,5 +1,5 @@
 /*
- * Copyright 2002 - 2007 JEuclid, http://jeuclid.sf.net
+ * Copyright 2002 - 2009 JEuclid, http://jeuclid.sf.net
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: AbstractJEuclidElement.java 872 2008-12-25 21:43:24Z maxberger $ */
+/* $Id: AbstractJEuclidElement.java,v 62d8defc665e 2009/09/25 14:22:59 max $ */
 
 package net.sourceforge.jeuclid.elements;
 
@@ -36,14 +36,16 @@ import net.sourceforge.jeuclid.elements.support.ElementListSupport;
 import net.sourceforge.jeuclid.elements.support.GraphicsSupport;
 import net.sourceforge.jeuclid.elements.support.attributes.AttributesHelper;
 import net.sourceforge.jeuclid.elements.support.attributes.MathVariant;
-import net.sourceforge.jeuclid.elements.support.text.CharConverter;
+import net.sourceforge.jeuclid.elements.support.text.TextContent;
 import net.sourceforge.jeuclid.layout.LayoutInfo;
 import net.sourceforge.jeuclid.layout.LayoutStage;
 import net.sourceforge.jeuclid.layout.LayoutView;
 import net.sourceforge.jeuclid.layout.LayoutableNode;
 
+import org.apache.batik.dom.AbstractDocument;
 import org.apache.batik.dom.GenericElementNS;
 import org.apache.batik.dom.events.DOMMutationEvent;
+import org.w3c.dom.Attr;
 import org.w3c.dom.Node;
 import org.w3c.dom.events.Event;
 import org.w3c.dom.mathml.MathMLElement;
@@ -51,10 +53,10 @@ import org.w3c.dom.mathml.MathMLMathElement;
 import org.w3c.dom.mathml.MathMLNodeList;
 
 /**
- * The basic class for all math elements. Every element class inherits from
- * this class. It provides basic functionality for drawing.
+ * The basic class for all math elements. Every element class inherits from this
+ * class. It provides basic functionality for drawing.
  * 
- * @version $Revision: 872 $
+ * @version $Revision: 62d8defc665e $
  */
 // CHECKSTYLE:OFF
 public abstract class AbstractJEuclidElement extends
@@ -134,6 +136,34 @@ public abstract class AbstractJEuclidElement extends
 
     private final Map<String, String> defaultMathAttributes = new HashMap<String, String>();
 
+    /**
+     * Default constructor. Sets MathML Namespace.
+     * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
+     */
+    public AbstractJEuclidElement(final String qname,
+            final AbstractDocument odoc) {
+        super(AbstractJEuclidElement.URI, qname, odoc);
+    }
+
+    /**
+     * Constructor to explicitly set the namespace.
+     * 
+     * @param nsUri
+     *            Namespace URI.
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
+     */
+    public AbstractJEuclidElement(final String nsUri, final String qname,
+            final AbstractDocument odoc) {
+        super(nsUri, qname, odoc);
+    }
+
     /**
      * Gets the used font. Everything regardes font, processed by MathBase
      * object.
@@ -380,28 +410,7 @@ public abstract class AbstractJEuclidElement extends
      * @return Text content.
      */
     public String getText() {
-        final String theText = this.getTextContent();
-        if (theText == null) {
-            return "";
-        } else {
-
-            final StringBuilder newText = new StringBuilder();
-
-            // As seen in 2.4.6
-            newText.append(theText.trim());
-
-            for (int i = 0; i < newText.length() - 1; i++) {
-                if (newText.charAt(i) <= AbstractJEuclidElement.TRIVIAL_SPACE_MAX
-                        && newText.charAt(i + 1) <= AbstractJEuclidElement.TRIVIAL_SPACE_MAX) {
-                    newText.deleteCharAt(i);
-                    // CHECKSTYLE:OFF
-                    // This is intentional
-                    i--;
-                    // CHECKSTYLE:ON
-                }
-            }
-            return CharConverter.convertEarly(newText.toString());
-        }
+        return TextContent.getText(this);
     }
 
     /** {@inheritDoc} */
@@ -442,8 +451,7 @@ public abstract class AbstractJEuclidElement extends
      *            Value of mathvariant.
      */
     public void setMathvariant(final String mathvariant) {
-        this.setAttribute(AbstractJEuclidElement.ATTR_MATHVARIANT,
-                mathvariant);
+        this.setAttribute(AbstractJEuclidElement.ATTR_MATHVARIANT, mathvariant);
     }
 
     /**
@@ -522,16 +530,15 @@ public abstract class AbstractJEuclidElement extends
 
     /**
      * Sets default values for math attributes. Default values are returned
-     * through getMathAttribute, but not stored in the actual DOM tree. This
-     * is necessary to support proper serialization.
+     * through getMathAttribute, but not stored in the actual DOM tree. This is
+     * necessary to support proper serialization.
      * 
      * @param key
      *            the attribute to set.
      * @param value
      *            value of the attribute.
      */
-    protected void setDefaultMathAttribute(final String key,
-            final String value) {
+    protected void setDefaultMathAttribute(final String key, final String value) {
         this.defaultMathAttributes.put(key, value);
     }
 
@@ -561,26 +568,36 @@ public abstract class AbstractJEuclidElement extends
      */
     protected String getMathAttribute(final String attrName,
             final boolean useDefault) {
-        String attrValue;
-        attrValue = this.getAttributeNS(AbstractJEuclidElement.URI, attrName)
-                .trim();
-        // TODO: Replace with .isEmpty when JEuclid moves to 1.6
-        if (attrValue.length() == 0) {
-            attrValue = this.getAttribute(attrName).trim();
-            if (attrValue.length() == 0) {
-                // CHECKSTYLE:OFF
-                // Third level here is no problem for readability.
-                if (useDefault) {
-                    // CHECKSTYLE:ON
-                    attrValue = this.defaultMathAttributes.get(attrName);
-                } else {
-                    attrValue = null;
-                }
+        final String attrValue;
+        Attr attr = this.getAttributeNodeNS(AbstractJEuclidElement.URI,
+                attrName);
+        if (attr == null) {
+            attr = this.getAttributeNode(attrName);
+        }
+        if (attr == null) {
+            if (useDefault) {
+                attrValue = this.getDefaultMathAttribute(attrName);
+            } else {
+                attrValue = null;
             }
+        } else {
+            attrValue = attr.getValue().trim();
         }
         return attrValue;
     }
 
+    /**
+     * Retrieves the previously stored default value for this attribute.
+     * 
+     * @param attrName
+     *            name of the Attribute
+     * @return value set by {@link #setDefaultMathAttribute(String, String)} or
+     *         null if not set.
+     */
+    private String getDefaultMathAttribute(final String attrName) {
+        return this.defaultMathAttributes.get(attrName);
+    }
+
     /**
      * Returns value of mathbackground attribute.
      * 
@@ -617,8 +634,7 @@ public abstract class AbstractJEuclidElement extends
      * @param g
      *            Graphics2D context to use.
      */
-    public float getMiddleShift(final Graphics2D g,
-            final LayoutContext context) {
+    public float getMiddleShift(final Graphics2D g, final LayoutContext context) {
         return this.getFontMetrics(g, context).getAscent()
                 * AbstractJEuclidElement.MIDDLE_SHIFT;
     }
@@ -640,9 +656,7 @@ public abstract class AbstractJEuclidElement extends
 
     /** {@inheritDoc} */
     public void setMathElementStyle(final String mathElementStyle) {
-        this
-                .setAttribute(AbstractJEuclidElement.ATTR_STYLE,
-                        mathElementStyle);
+        this.setAttribute(AbstractJEuclidElement.ATTR_STYLE, mathElementStyle);
     }
 
     /** {@inheritDoc} */
@@ -721,7 +735,7 @@ public abstract class AbstractJEuclidElement extends
      *            external context.
      * @return the current layout context.
      */
-    protected LayoutContext applyLocalAttributesToContext(
+    public LayoutContext applyLocalAttributesToContext(
             final LayoutContext context) {
         // TODO: Theoretically this only applies all to presentation token
         // elements except mspace and mglyph, and on no other elements except
@@ -734,8 +748,8 @@ public abstract class AbstractJEuclidElement extends
      * 
      * @param applyTo
      *            the context to apply to
-     * @return a context which has the style attributes changed accordingly.
-     *         May be the original context if nothing has changed.
+     * @return a context which has the style attributes changed accordingly. May
+     *         be the original context if nothing has changed.
      */
     private LayoutContext applyStyleAttributes(final LayoutContext applyTo) {
         LayoutContext retVal = applyTo;
@@ -757,8 +771,7 @@ public abstract class AbstractJEuclidElement extends
         // context.
 
         if ((msize != null) || (foreground != null)) {
-            retVal = new StyleAttributeLayoutContext(applyTo, msize,
-                    foreground);
+            retVal = new StyleAttributeLayoutContext(applyTo, msize, foreground);
         }
 
         return retVal;
@@ -843,8 +856,7 @@ public abstract class AbstractJEuclidElement extends
         AbstractJEuclidElement.DEPRECATED_ATTRIBUTES
                 .add(AbstractJEuclidElement.ATTR_DEPRECATED_FONTFAMILY);
 
-        AbstractJEuclidElement.DEPRECATED_ATTRIBUTES
-                .add(Mo.ATTR_MOVEABLEWRONG);
+        AbstractJEuclidElement.DEPRECATED_ATTRIBUTES.add(Mo.ATTR_MOVEABLEWRONG);
     }
 
     /**
