@@ -14,18 +14,19 @@
  * limitations under the License.
  */
 
-/* $Id: Mn.java 718 2008-04-28 18:46:38Z maxberger $ */
+/* $Id: Mn.java,v 923658a2b249 2009/09/11 09:57:31 max $ */
 
 package net.sourceforge.jeuclid.elements.presentation.token;
 
+import org.apache.batik.dom.AbstractDocument;
 import org.w3c.dom.Node;
 
 /**
  * This class presents numbers in a equation.
  * 
- * @version $Revision: 718 $
+ * @version $Revision: 923658a2b249 $
  */
-public final class Mn extends AbstractTokenWithStandardLayout {
+public final class Mn extends AbstractTokenWithTextLayout {
 
     /**
      * The XML element from this class.
@@ -35,16 +36,21 @@ public final class Mn extends AbstractTokenWithStandardLayout {
     private static final long serialVersionUID = 1L;
 
     /**
-     * Default constructor.
+     * Default constructor. Sets MathML Namespace.
+     * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
      */
-    public Mn() {
-        super();
+    public Mn(final String qname, final AbstractDocument odoc) {
+        super(qname, odoc);
     }
 
     /** {@inheritDoc} */
     @Override
     protected Node newNode() {
-        return new Mn();
+        return new Mn(this.nodeName, this.ownerDocument);
     }
 
 }
