@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: Mo.java 902 2009-03-20 11:32:25Z maxberger $ */
+/* $Id: Mo.java,v e2b3e25686bf 2009/09/29 19:14:25 max $ */
 
 package net.sourceforge.jeuclid.elements.presentation.token;
 
@@ -34,6 +34,7 @@ import net.sourceforge.jeuclid.elements.presentation.general.Mrow;
 import net.sourceforge.jeuclid.elements.support.GraphicsSupport;
 import net.sourceforge.jeuclid.elements.support.attributes.AttributesHelper;
 import net.sourceforge.jeuclid.elements.support.operatordict.OperatorDictionary;
+import net.sourceforge.jeuclid.elements.support.operatordict.OperatorDictionary2;
 import net.sourceforge.jeuclid.elements.support.operatordict.UnknownAttributeException;
 import net.sourceforge.jeuclid.elements.support.text.StringUtil;
 import net.sourceforge.jeuclid.elements.support.text.StringUtil.TextLayoutInfo;
@@ -42,19 +43,22 @@ import net.sourceforge.jeuclid.layout.LayoutStage;
 import net.sourceforge.jeuclid.layout.LayoutView;
 import net.sourceforge.jeuclid.layout.TextObject;
 
+import org.apache.batik.dom.AbstractDocument;
 import org.apache.batik.dom.events.DOMCustomEvent;
+import org.w3c.dom.Attr;
 import org.w3c.dom.Node;
 import org.w3c.dom.events.CustomEvent;
 import org.w3c.dom.events.Event;
 import org.w3c.dom.events.EventListener;
 import org.w3c.dom.events.EventTarget;
 import org.w3c.dom.mathml.MathMLOperatorElement;
+import org.w3c.dom.mathml.MathMLScriptElement;
 import org.w3c.dom.mathml.MathMLUnderOverElement;
 
 /**
  * This class presents a math operator, like "(" or "*".
  * 
- * @version $Revision: 902 $
+ * @version $Revision: e2b3e25686bf $
  */
 
 // CHECKSTYLE:OFF
@@ -111,6 +115,11 @@ public final class Mo extends AbstractJEuclidElement implements
      */
     public static final String ATTR_STRETCHY = "stretchy";
 
+    /** JEuclid extension to stretchy: stretch horizontal only. */
+    public static final String VALUE_STRETCHY_HORIZONTAL = "horizontal";
+
+    /** JEuclid extension to stretchy: stretch vertical only. */
+    public static final String VALUE_STRETCHY_VERTICAL = "vertical";
     /**
      * Attribute name of the largeop property.
      */
@@ -131,34 +140,6 @@ public final class Mo extends AbstractJEuclidElement implements
      */
     public static final String MOEVENT = "MOEvent";
 
-    /**
-     * Horizontal delimiters.
-     * 
-     * @todo Check the uncommented ones, possibly add more / remove some?
-     */
-    public static final String HOR_DELIMITERS = /* _ */"\u005F"
-            + /* OverBar */"\u00AF" + /* UnderBar */"\u0332" + "\u0333"
-            + "\u033F" + "\u2190" + "\u2192" + "\u2194"
-            + /* OverBracket */"\u23B4" + /* UnderBracket */"\u23B5"
-            + /* OverParenthesis */"\uFE35"
-            + /* UnderParenthesis */"\uFE36" + /* OverBrace */"\uFE37"
-            + /* UnderBrace */"\uFE38" + /* Frown */"\u2322";
-
-    /**
-     * Vertical delimiters.
-     * 
-     * @todo Add others (?)
-     */
-    public static final String VER_DELIMITERS = "[{()}]|"
-            + /* Up Arrow */"\u2191" + /* Down Arrow */"\u2193" + /*
-                                                                   * Up Arrow
-                                                                   * Down
-                                                                   * Arrow
-                                                                   */"\u21C5"
-            + /* Up Arrow Up Arrow */"\u21C8"
-            + /* Down Down Arrows */"\u21CA"
-            + /* Down Arrow Up Arrow */"\u21F5" + "\u2223\u2225\u2329\u232A";
-
     private static final long serialVersionUID = 1L;
 
     private final OperatorDictionary opDict;
@@ -172,10 +153,16 @@ public final class Mo extends AbstractJEuclidElement implements
     // private static final Log LOGGER =
     // LogFactory.getLog(MathOperator.class);
     /**
-     * Creates a mathoperator element.
+     * Default constructor. Sets MathML Namespace.
+     * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
      */
-    public Mo() {
-        super();
+    public Mo(final String qname, final AbstractDocument odoc) {
+        super(qname, odoc);
+
         this.setDefaultMathAttribute(Mo.ATTR_FORM,
                 OperatorDictionary.FORM_INFIX);
         this.setDefaultMathAttribute(Mo.ATTR_FENCE, Constants.FALSE);
@@ -186,19 +173,20 @@ public final class Mo extends AbstractJEuclidElement implements
                 AttributesHelper.THICKMATHSPACE);
         this.setDefaultMathAttribute(Mo.ATTR_STRETCHY, Constants.FALSE);
         this.setDefaultMathAttribute(Mo.ATTR_SYMMETRIC, Constants.TRUE);
-        this.setDefaultMathAttribute(Mo.ATTR_MAXSIZE,
-                AttributesHelper.INFINITY);
+        this
+                .setDefaultMathAttribute(Mo.ATTR_MAXSIZE,
+                        AttributesHelper.INFINITY);
         this.setDefaultMathAttribute(Mo.ATTR_MINSIZE, "1");
         this.setDefaultMathAttribute(Mo.ATTR_LARGEOP, Constants.FALSE);
         this.setDefaultMathAttribute(Mo.ATTR_MOVABLELIMITS, Constants.FALSE);
         this.setDefaultMathAttribute(Mo.ATTR_ACCENT, Constants.FALSE);
-        this.opDict = OperatorDictionary.getInstance();
+        this.opDict = OperatorDictionary2.getInstance();
     }
 
     /** {@inheritDoc} */
     @Override
     protected Node newNode() {
-        return new Mo();
+        return new Mo(this.nodeName, this.ownerDocument);
     }
 
     /**
@@ -285,17 +273,6 @@ public final class Mo extends AbstractJEuclidElement implements
         return this.getMathAttribute(Mo.ATTR_MINSIZE);
     }
 
-    private boolean isVerticalDelimeter() {
-        return this.getText().length() == 1
-                && (Mo.VER_DELIMITERS.indexOf(this.getText().charAt(0)) >= 0 || this
-                        .isFence());
-    }
-
-    private boolean isHorizontalDelimeter() {
-        return this.getText().length() == 1
-                && (Mo.HOR_DELIMITERS.indexOf(this.getText().charAt(0)) >= 0);
-    }
-
     private TextLayout produceUnstrechtedLayout(final Graphics2D g,
             final LayoutContext now) {
         assert g != null : "Graphics2d is null in produceUnstrechtedLayout";
@@ -320,13 +297,9 @@ public final class Mo extends AbstractJEuclidElement implements
         if (!this.inChangeHook) {
             this.inChangeHook = true;
             this.detectFormParameter();
-            this
-                    .loadAttributeFromDictionary(Mo.ATTR_LARGEOP,
-                            Constants.FALSE);
-            this.loadAttributeFromDictionary(Mo.ATTR_SYMMETRIC,
-                    Constants.TRUE);
-            this.loadAttributeFromDictionary(Mo.ATTR_STRETCHY,
-                    Constants.FALSE);
+            this.loadAttributeFromDictionary(Mo.ATTR_LARGEOP, Constants.FALSE);
+            this.loadAttributeFromDictionary(Mo.ATTR_SYMMETRIC, Constants.TRUE);
+            this.loadAttributeFromDictionary(Mo.ATTR_STRETCHY, Constants.FALSE);
             this.loadAttributeFromDictionary(Mo.ATTR_FENCE, Constants.FALSE);
             this.loadAttributeFromDictionary(Mo.ATTR_LSPACE,
                     AttributesHelper.THICKMATHSPACE);
@@ -335,24 +308,10 @@ public final class Mo extends AbstractJEuclidElement implements
             this.loadAttributeFromDictionary(Mo.ATTR_MOVABLELIMITS,
                     Constants.FALSE);
             // TODO: Load all.
-
-            JEuclidElement parent = this.getParent();
-            while (parent != null) {
-                if (parent instanceof EventTarget) {
-                    ((EventTarget) parent).addEventListener(
-                            "DOMSubtreeModified", this, false);
-                }
-                if (parent instanceof Mrow) {
-                    parent = null;
-                } else {
-                    parent = parent.getParent();
-                }
-            }
-
+            this.registerWithParentsForEvents();
             if (this.isFence()) {
-                this
-                        .setDefaultMathAttribute(Mo.ATTR_STRETCHY,
-                                Constants.TRUE);
+                this.setDefaultMathAttribute(Mo.ATTR_STRETCHY,
+                        Mo.VALUE_STRETCHY_VERTICAL);
             }
             final CustomEvent evt = new DOMCustomEvent();
             evt.initCustomEventNS(null, Mo.MOEVENT, true, false, null);
@@ -361,6 +320,21 @@ public final class Mo extends AbstractJEuclidElement implements
         }
     }
 
+    private void registerWithParentsForEvents() {
+        JEuclidElement parent = this.getParent();
+        while (parent != null) {
+            if (parent instanceof EventTarget) {
+                ((EventTarget) parent).addEventListener("DOMSubtreeModified",
+                        this, false);
+            }
+            if ((parent instanceof Mrow) && (parent.getMathElementCount() > 1)) {
+                parent = null;
+            } else {
+                parent = parent.getParent();
+            }
+        }
+    }
+
     private void loadAttributeFromDictionary(final String attrname,
             final String defvalue) {
         String attr;
@@ -380,13 +354,13 @@ public final class Mo extends AbstractJEuclidElement implements
     private void detectFormParameter() {
         final String form;
         final JEuclidElement parent = this.getParent();
-        if (parent != null && (parent instanceof Mrow)) {
+        if ((parent != null) && (parent instanceof Mrow)) {
             final int index = parent.getIndexOfMathElement(this);
-            if (index == 0 && parent.getMathElementCount() > 0) {
+            if ((index == 0) && (parent.getMathElementCount() > 0)) {
                 form = OperatorDictionary.FORM_PREFIX;
             } else {
-                if (index == (parent.getMathElementCount() - 1)
-                        && parent.getMathElementCount() > 0) {
+                if ((index == (parent.getMathElementCount() - 1))
+                        && (parent.getMathElementCount() > 0)) {
                     form = OperatorDictionary.FORM_POSTFIX;
                 } else {
                     form = OperatorDictionary.FORM_INFIX;
@@ -490,9 +464,51 @@ public final class Mo extends AbstractJEuclidElement implements
         return this.getMathAttribute(Mo.ATTR_SEPARATOR);
     }
 
+    /**
+     * Retrieves the JEuclid specific extension of the stretch attribute. This
+     * method may return {@link Constants#TRUE}, {@link Constants#FALSE},
+     * {@link #VALUE_STRETCHY_HORIZONTAL}, {@link #VALUE_STRETCHY_VERTICAL}, or
+     * null if no stretchy attribute is set.
+     * 
+     * @return an JEuclid stretchy attribute.
+     */
+    public String getExtendedStretchy() {
+        final String retVal;
+        final Attr attr = this.getAttributeNodeNS(Constants.NS_JEUCLID_EXT,
+                Mo.ATTR_STRETCHY);
+        if (attr == null) {
+            retVal = this.getMathAttribute(Mo.ATTR_STRETCHY);
+        } else {
+            retVal = attr.getValue().trim();
+        }
+        return retVal;
+    }
+
     /** {@inheritDoc} */
     public String getStretchy() {
-        return this.getMathAttribute(Mo.ATTR_STRETCHY);
+        final String stretchVal = this.getExtendedStretchy();
+        if ((Mo.VALUE_STRETCHY_HORIZONTAL.equalsIgnoreCase(stretchVal))
+                || (Mo.VALUE_STRETCHY_VERTICAL.equalsIgnoreCase(stretchVal))) {
+            return Constants.TRUE;
+        } else {
+            return stretchVal;
+        }
+    }
+
+    private boolean isStretchyHorizontal(final String stretchValue) {
+        return Mo.VALUE_STRETCHY_HORIZONTAL.equalsIgnoreCase(stretchValue)
+                || Boolean.parseBoolean(stretchValue);
+    }
+
+    private boolean isStretchyVertical(final String stretchValue) {
+        return Mo.VALUE_STRETCHY_VERTICAL.equalsIgnoreCase(stretchValue)
+                || Boolean.parseBoolean(stretchValue);
+    }
+
+    private boolean isStretchy() {
+        final String stretchValue = this.getExtendedStretchy();
+        return this.isStretchyHorizontal(stretchValue)
+                || this.isStretchyVertical(stretchValue);
     }
 
     /** {@inheritDoc} */
@@ -505,6 +521,10 @@ public final class Mo extends AbstractJEuclidElement implements
         return this.getMathAttribute(Mo.ATTR_SYMMETRIC);
     }
 
+    private boolean isSymmetric() {
+        return Boolean.parseBoolean(this.getSymmetric());
+    }
+
     /** {@inheritDoc} */
     @Override
     public void layoutStage1(final LayoutView view, final LayoutInfo info,
@@ -538,13 +558,13 @@ public final class Mo extends AbstractJEuclidElement implements
         info.setHorizontalCenterOffset(lspace + contentWidth / 2.0f,
                 LayoutStage.STAGE1);
         info.setWidth(lspace + contentWidth + rspace, LayoutStage.STAGE1);
-        if (Boolean.parseBoolean(this.getStretchy())
-                || this.isVerticalDelimeter() || this.isHorizontalDelimeter()) {
+        if (this.isStretchy()) {
             info.setLayoutStage(LayoutStage.STAGE1);
+            info.setStretchAscent(0.0f);
+            info.setStretchDescent(0.0f);
         } else {
-            info.setGraphicsObject(new TextObject(t,
-                    lspace + tli.getOffset(), 0, null, (Color) now
-                            .getParameter(Parameter.MATHCOLOR)));
+            info.setGraphicsObject(new TextObject(t, lspace + tli.getOffset(),
+                    0, null, (Color) now.getParameter(Parameter.MATHCOLOR)));
             info.setLayoutStage(LayoutStage.STAGE2);
         }
     }
@@ -561,27 +581,69 @@ public final class Mo extends AbstractJEuclidElement implements
         final float calcScaleY;
         final float calcScaleX;
         final float calcBaselineShift;
-        final boolean stretchVertically = this.isVerticalDelimeter();
-        JEuclidElement parent = this.getParent();
-        while ((((parent instanceof MathMLUnderOverElement) && stretchVertically) || ((parent instanceof Mrow) && (parent
-                .getMathElementCount() == 1)))
-                && (parent.getParent() != null)) {
+        final String stretchValue = this.getExtendedStretchy();
+        boolean stretchVertically = this.isStretchyVertical(stretchValue);
+        final boolean stretchHorizontally = this
+                .isStretchyHorizontal(stretchValue);
+
+        JEuclidElement horizParent = null;
+        JEuclidElement parent = this;
+        JEuclidElement last;
+        boolean cont;
+        do {
+            last = parent;
             parent = parent.getParent();
+            cont = false;
+            if ((parent instanceof Mrow) && (parent.getMathElementCount() == 1)) {
+                // Ignore single element Mrows.
+                cont = true;
+            } else if ((parent instanceof MathMLUnderOverElement)
+                    || (parent instanceof MathMLScriptElement)) {
+                // Special Treatment for UnderOverElements to match stretchVert1
+                // test.
+                final boolean isBase;
+                if (parent instanceof MathMLUnderOverElement) {
+                    final MathMLUnderOverElement munderover = (MathMLUnderOverElement) parent;
+                    isBase = munderover.getBase() == last;
+                } else {
+                    final MathMLScriptElement munderover = (MathMLScriptElement) parent;
+                    isBase = munderover.getBase() == last;
+                }
+                if (!isBase) {
+                    stretchVertically = false;
+                }
+                horizParent = parent;
+                cont = true;
+            }
+        } while (cont);
+        if (horizParent == null) {
+            horizParent = parent;
         }
+
         final LayoutInfo parentInfo = view.getInfo(parent);
         final TextLayoutInfo textLayoutInfo = StringUtil.getTextLayoutInfo(t,
                 true);
-        if (stretchVertically) {
-            final float[] yf = this.calcYScaleFactorAndBaselineShift(info,
-                    parentInfo, textLayoutInfo, now);
-            calcScaleY = yf[0];
-            calcBaselineShift = yf[1];
-        } else {
+        if (parentInfo == null) {
+            calcScaleX = 1.0f;
             calcScaleY = 1.0f;
             calcBaselineShift = 0.0f;
+        } else {
+            if (stretchVertically) {
+                final float[] yf = this.calcYScaleFactorAndBaselineShift(info,
+                        parentInfo, textLayoutInfo, now, g);
+                calcScaleY = yf[0];
+                calcBaselineShift = yf[1];
+            } else {
+                calcScaleY = 1.0f;
+                calcBaselineShift = 0.0f;
+            }
+            if (stretchHorizontally) {
+                calcScaleX = this.calcXScaleFactor(info, view
+                        .getInfo(horizParent), textLayoutInfo);
+            } else {
+                calcScaleX = 1.0f;
+            }
         }
-        calcScaleX = this.calcXScaleFactor(info, parentInfo, textLayoutInfo);
-
         info.setGraphicsObject(new TextObject(t, this.getLspaceAsFloat(now)
                 + textLayoutInfo.getOffset() * calcScaleX, calcBaselineShift,
                 AffineTransform.getScaleInstance(calcScaleX, calcScaleY),
@@ -592,10 +654,11 @@ public final class Mo extends AbstractJEuclidElement implements
     private float calcXScaleFactor(final LayoutInfo info,
             final LayoutInfo parentInfo, final TextLayoutInfo textLayoutInfo) {
         final float calcScaleX;
-        final float stretchWidth = parentInfo.getStretchWidth();
-        if ((this.isHorizontalDelimeter()) && (stretchWidth > 0.0f)) {
+        final float rstretchWidth = parentInfo.getStretchWidth();
+        if (rstretchWidth > 0.0f) {
             final float realwidth = textLayoutInfo.getWidth();
             if (realwidth > 0) {
+                final float stretchWidth = Math.max(realwidth, rstretchWidth);
                 calcScaleX = stretchWidth / realwidth;
                 info.setWidth(stretchWidth, LayoutStage.STAGE2);
                 info.setHorizontalCenterOffset(stretchWidth / 2.0f,
@@ -611,16 +674,34 @@ public final class Mo extends AbstractJEuclidElement implements
 
     private float[] calcYScaleFactorAndBaselineShift(final LayoutInfo info,
             final LayoutInfo parentInfo, final TextLayoutInfo textLayoutInfo,
-            final LayoutContext now) {
+            final LayoutContext now, final Graphics2D g2d) {
         final float calcScaleY;
         final float calcBaselineShift;
-        final float targetNAscent = parentInfo.getStretchAscent();
-        final float targetNDescent = parentInfo.getStretchDescent();
-
-        final float targetNHeight = targetNAscent + targetNDescent;
-
         final float realDescent = textLayoutInfo.getDescent();
-        final float realHeight = textLayoutInfo.getAscent() + realDescent;
+        final float realAscent = textLayoutInfo.getAscent();
+        float targetNAscent;
+        float targetNDescent;
+        if (this.isFence()) {
+            targetNAscent = Math.max(parentInfo
+                    .getAscentHeight(LayoutStage.STAGE1), realAscent);
+            targetNDescent = Math.max(parentInfo
+                    .getDescentHeight(LayoutStage.STAGE1), realDescent);
+        } else {
+            targetNAscent = Math.max(parentInfo.getStretchAscent(), realAscent);
+            targetNDescent = Math.max(parentInfo.getStretchDescent(),
+                    realDescent);
+        }
+        if (this.isSymmetric()) {
+            final float middle = this.getMiddleShift(g2d, now);
+            final float ascentAboveMiddle = targetNAscent - middle;
+            final float descentBelowMiddle = targetNDescent + middle;
+            final float halfHeight = Math.max(ascentAboveMiddle,
+                    descentBelowMiddle);
+            targetNAscent = halfHeight + middle;
+            targetNDescent = halfHeight - middle;
+        }
+        final float targetNHeight = targetNAscent + targetNDescent;
+        final float realHeight = realAscent + realDescent;
 
         // TODO: MaxSize / MinSize could also be inherited from MStyle.
         final float maxSize = AttributesHelper.parseRelativeSize(this
@@ -642,9 +723,7 @@ public final class Mo extends AbstractJEuclidElement implements
         calcBaselineShift = targetDescent - realDescentScaled;
 
         info.setDescentHeight(targetDescent, LayoutStage.STAGE2);
-        info
-                .setAscentHeight(targetHeight - targetDescent,
-                        LayoutStage.STAGE2);
+        info.setAscentHeight(targetHeight - targetDescent, LayoutStage.STAGE2);
         return new float[] { calcScaleY, calcBaselineShift };
     }
 
