@@ -14,18 +14,19 @@
  * limitations under the License.
  */
 
-/* $Id: Mtext.java 750 2008-05-18 22:22:38Z maxberger $ */
+/* $Id: Mtext.java,v 923658a2b249 2009/09/11 09:57:31 max $ */
 
 package net.sourceforge.jeuclid.elements.presentation.token;
 
+import org.apache.batik.dom.AbstractDocument;
 import org.w3c.dom.Node;
 
 /**
  * This class presents text in a equation and contains some utility methods.
  * 
- * @version $Revision: 750 $
+ * @version $Revision: 923658a2b249 $
  */
-public final class Mtext extends AbstractTokenWithStandardLayout {
+public final class Mtext extends AbstractTokenWithTextLayout {
     /**
      * The XML element from this class.
      */
@@ -34,17 +35,21 @@ public final class Mtext extends AbstractTokenWithStandardLayout {
     private static final long serialVersionUID = 1L;
 
     /**
-     * Creates a math element.
+     * Default constructor. Sets MathML Namespace.
      * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
      */
-    public Mtext() {
-        super();
+    public Mtext(final String qname, final AbstractDocument odoc) {
+        super(qname, odoc);
     }
 
     /** {@inheritDoc} */
     @Override
     protected Node newNode() {
-        return new Mtext();
+        return new Mtext(this.nodeName, this.ownerDocument);
     }
 
 }
