@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: AttributesHelper.java 792 2008-06-14 16:14:40Z maxberger $ */
+/* $Id: AttributesHelper.java,v cae99f384592 2009/06/03 12:42:28 maxberger $ */
 
 package net.sourceforge.jeuclid.elements.support.attributes;
 
@@ -36,7 +36,7 @@ import org.apache.commons.logging.LogFactory;
 /**
  * Class contains utility methods for working with elements attributes.
  * 
- * @version $Revision: 792 $
+ * @version $Revision: cae99f384592 $
  */
 public final class AttributesHelper {
 
@@ -287,7 +287,7 @@ public final class AttributesHelper {
         }
         if (tSize.endsWith(AttributesHelper.PERCENT_SIGN)) {
             // A nice trick because all other units are exactly 2 chars long.
-            tSize += " ";
+            tSize = new StringBuilder(tSize).append(' ').toString();
         }
         return tSize;
     }
