@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: CharacterMapping.java 887 2009-02-10 13:15:15Z maxberger $ */
+/* $Id: CharacterMapping.java,v a96da3a7efbd 2009/07/13 13:34:06 maxberger $ */
 
 package net.sourceforge.jeuclid.elements.support.text;
 
@@ -45,7 +45,7 @@ import org.apache.commons.logging.LogFactory;
 import org.apache.xmlgraphics.fonts.Glyphs;
 
 /**
- * @version $Revision: 887 $
+ * @version $Revision: a96da3a7efbd $
  */
 public final class CharacterMapping implements Serializable {
 
@@ -101,7 +101,7 @@ public final class CharacterMapping implements Serializable {
 
     private void loadUnicodeData() {
         final InputStream is = CharacterMapping.class
-                .getResourceAsStream("/UnicodeData.txt");
+                .getResourceAsStream("/net/sourceforge/jeuclid/UnicodeData.txt");
         try {
             final BufferedReader r = new BufferedReader(
                     new InputStreamReader(is));
@@ -229,7 +229,7 @@ public final class CharacterMapping implements Serializable {
             CharacterMapping m;
             try {
                 final InputStream is = CharacterMapping.class
-                        .getResourceAsStream("/charmap.ser");
+                        .getResourceAsStream("/net/sourceforge/jeuclid/charmap.ser");
                 final ObjectInput oi = new ObjectInputStream(is);
                 m = (CharacterMapping) oi.readObject();
                 oi.close();
