@@ -1,5 +1,5 @@
 /*
- * Copyright 2007 - 2008 JEuclid, http://jeuclid.sf.net
+ * Copyright 2007 - 2009 JEuclid, http://jeuclid.sf.net
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: DOMModelTest.java 858 2008-11-28 12:13:29Z maxberger $ */
+/* $Id: DOMModelTest.java,v b4b0786c4d39 2009/08/28 14:04:47 max $ */
 
 package net.sourceforge.jeuclid.test;
 
@@ -102,7 +102,7 @@ import org.w3c.dom.mathml.MathMLUnderOverElement;
 /**
  * Various tests for the DOM model.
  * 
- * @version $Revision: 858 $
+ * @version $Revision: b4b0786c4d39 $
  */
 // CHECKSTYLE:OFF
 public class DOMModelTest {
@@ -154,17 +154,17 @@ public class DOMModelTest {
      */
     @Test
     public void testSerialization() throws Exception {
-        final Document origDoc = MathMLParserSupport
-                .parseString("<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?><math mode=\"display\">"
-                        + "<mrow id='abc'><mn>1</mn></mrow></math>");
+        final String shouldBe = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?><math mode=\"display\" xmlns='http://www.w3.org/1998/Math/MathML'>"
+                + "<mrow id='abc'><mn>1</mn></mrow></math>";
+        final Document origDoc = MathMLParserSupport.parseString(shouldBe);
         final MathMLDocument mathMLDoc = DOMBuilder.getInstance()
                 .createJeuclidDom(origDoc);
         final String reserialStr = MathMLSerializer.serializeDocument(
                 mathMLDoc, false, false);
 
-        final Document reserial = MathMLParserSupport
-                .parseString(reserialStr);
-        Assert.assertTrue(reserial.isEqualNode(origDoc));
+        final Document reserial = MathMLParserSupport.parseString(reserialStr);
+        Assert.assertTrue(reserial.isEqualNode(origDoc), "is: " + reserialStr
+                + "\nshould be: " + shouldBe);
     }
 
     /**
@@ -175,17 +175,17 @@ public class DOMModelTest {
      */
     @Test
     public void testSerialization2() throws Exception {
-        final Document origDoc = MathMLParserSupport
-                .parseString("<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?><math mode=\"display\">"
-                        + "<mtext>Alignment<malignmark/>Test</mtext></math>");
+        final String shouldBe = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?><math mode=\"display\" xmlns='http://www.w3.org/1998/Math/MathML'>"
+                + "<mtext>Alignment<malignmark/>Test</mtext></math>";
+        final Document origDoc = MathMLParserSupport.parseString(shouldBe);
         final MathMLDocument mathMLDoc = DOMBuilder.getInstance()
                 .createJeuclidDom(origDoc);
         final String reserialStr = MathMLSerializer.serializeDocument(
                 mathMLDoc, false, false);
 
-        final Document reserial = MathMLParserSupport
-                .parseString(reserialStr);
-        Assert.assertTrue(reserial.isEqualNode(origDoc));
+        final Document reserial = MathMLParserSupport.parseString(reserialStr);
+        Assert.assertTrue(reserial.isEqualNode(origDoc), "is: " + reserialStr
+                + "\nshould be: " + shouldBe);
     }
 
     /**
@@ -202,7 +202,10 @@ public class DOMModelTest {
                         + "<mo stretchy='false'>Y</mo>"
                         + "<mo>&#x0007d;</mo>"
                         + "<mo>&#x02254;</mo>"
-                        + "<mo>&#x0201d;</mo>" + "</math>");
+                        + "<mo>&#x0201d;</mo>"
+                        + "<mo stretchy='false'>)</mo>"
+                        + "<mo>)</mo>"
+                        + "</math>");
         final MathMLDocument docElement = DOMBuilder.getInstance()
                 .createJeuclidDom(doc);
 
@@ -221,8 +224,12 @@ public class DOMModelTest {
         Assert.assertTrue(Boolean.parseBoolean(mo3.getStretchy()));
         final Mo mo4 = (Mo) mathElement.getChildNodes().item(3);
         Assert.assertFalse(Boolean.parseBoolean(mo4.getStretchy()));
-        final Mo mo5 = (Mo) mathElement.getChildNodes().item(2);
+        final Mo mo5 = (Mo) mathElement.getChildNodes().item(4);
         Assert.assertTrue(Boolean.parseBoolean(mo5.getStretchy()));
+        final Mo mo6 = (Mo) mathElement.getChildNodes().item(5);
+        Assert.assertFalse(Boolean.parseBoolean(mo6.getStretchy()));
+        final Mo mo7 = (Mo) mathElement.getChildNodes().item(6);
+        Assert.assertTrue(Boolean.parseBoolean(mo7.getStretchy()));
     }
 
     /**
@@ -241,72 +248,74 @@ public class DOMModelTest {
         // TODO: Use DOM instead;
         final Document ownerDocument = new DocumentElement();
 
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("math",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "math",
                 ownerDocument) instanceof MathMLMathElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mi",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mi",
                 ownerDocument) instanceof MathMLPresentationToken);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mn",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mn",
                 ownerDocument) instanceof MathMLPresentationToken);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mo",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mo",
                 ownerDocument) instanceof MathMLOperatorElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mtext",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mtext",
                 ownerDocument) instanceof MathMLPresentationToken);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mspace",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mspace",
                 ownerDocument) instanceof MathMLSpaceElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("ms",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "ms",
                 ownerDocument) instanceof MathMLStringLitElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mglyph",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mglyph",
                 ownerDocument) instanceof MathMLGlyphElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mrow",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mrow",
                 ownerDocument) instanceof MathMLPresentationContainer);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mfrac",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mfrac",
                 ownerDocument) instanceof MathMLFractionElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("msqrt",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "msqrt",
                 ownerDocument) instanceof MathMLRadicalElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mroot",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mroot",
                 ownerDocument) instanceof MathMLRadicalElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mstyle",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mstyle",
                 ownerDocument) instanceof MathMLStyleElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("merror",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "merror",
                 ownerDocument) instanceof MathMLPresentationContainer);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mpadded",
-                ownerDocument) instanceof MathMLPaddedElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mphantom",
-                ownerDocument) instanceof MathMLPresentationContainer);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mfenced",
-                ownerDocument) instanceof MathMLFencedElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("menclose",
-                ownerDocument) instanceof MathMLEncloseElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("msub",
-                ownerDocument) instanceof MathMLScriptElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("msup",
-                ownerDocument) instanceof MathMLScriptElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("msubsup",
-                ownerDocument) instanceof MathMLScriptElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("munder",
-                ownerDocument) instanceof MathMLUnderOverElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mover",
-                ownerDocument) instanceof MathMLUnderOverElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("munderover",
-                ownerDocument) instanceof MathMLUnderOverElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null,
+                "mpadded", ownerDocument) instanceof MathMLPaddedElement);
         Assert
-                .assertTrue(JEuclidElementFactory.elementFromName(
+                .assertTrue(JEuclidElementFactory.elementFromName(null,
+                        "mphantom", ownerDocument) instanceof MathMLPresentationContainer);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null,
+                "mfenced", ownerDocument) instanceof MathMLFencedElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null,
+                "menclose", ownerDocument) instanceof MathMLEncloseElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "msub",
+                ownerDocument) instanceof MathMLScriptElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "msup",
+                ownerDocument) instanceof MathMLScriptElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null,
+                "msubsup", ownerDocument) instanceof MathMLScriptElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "munder",
+                ownerDocument) instanceof MathMLUnderOverElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mover",
+                ownerDocument) instanceof MathMLUnderOverElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null,
+                "munderover", ownerDocument) instanceof MathMLUnderOverElement);
+        Assert
+                .assertTrue(JEuclidElementFactory.elementFromName(null,
                         "mmultiscripts", ownerDocument) instanceof MathMLMultiScriptsElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mtable",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mtable",
                 ownerDocument) instanceof MathMLTableElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mlabeledtr",
-                ownerDocument) instanceof MathMLLabeledRowElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mtr",
+        Assert
+                .assertTrue(JEuclidElementFactory.elementFromName(null,
+                        "mlabeledtr", ownerDocument) instanceof MathMLLabeledRowElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mtr",
                 ownerDocument) instanceof MathMLTableRowElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("mtd",
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null, "mtd",
                 ownerDocument) instanceof MathMLTableCellElement);
         Assert
-                .assertTrue(JEuclidElementFactory.elementFromName(
+                .assertTrue(JEuclidElementFactory.elementFromName(null,
                         "maligngroup", ownerDocument) instanceof MathMLAlignGroupElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("malignmark",
-                ownerDocument) instanceof MathMLAlignMarkElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("maction",
-                ownerDocument) instanceof MathMLActionElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null,
+                "malignmark", ownerDocument) instanceof MathMLAlignMarkElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null,
+                "maction", ownerDocument) instanceof MathMLActionElement);
         // Assert
         // .assertTrue(MathElementFactory.elementFromName("cn", aMap,
         // base) instanceof MathMLCnElement);
@@ -612,10 +621,11 @@ public class DOMModelTest {
         // aMap) instanceof MathMLPredefinedSymbol);
         // Assert.assertTrue(MathElementFactory.elementFromName("outerproduct",
         // aMap) instanceof MathMLPredefinedSymbol);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("annotation",
-                ownerDocument) instanceof MathMLAnnotationElement);
-        Assert.assertTrue(JEuclidElementFactory.elementFromName("semantics",
-                ownerDocument) instanceof MathMLSemanticsElement);
+        Assert
+                .assertTrue(JEuclidElementFactory.elementFromName(null,
+                        "annotation", ownerDocument) instanceof MathMLAnnotationElement);
+        Assert.assertTrue(JEuclidElementFactory.elementFromName(null,
+                "semantics", ownerDocument) instanceof MathMLSemanticsElement);
         // Assert
         // .assertTrue(MathElementFactory.elementFromName(
         // "annotation-xml", aMap) instanceof
@@ -802,12 +812,11 @@ public class DOMModelTest {
                     }
                 }, false);
         mathElement.appendChild(docElement.createElement(Mi.ELEMENT));
-        Assert
-                .assertTrue(this.miCount == 0,
-                        "Event must not be called on Mi");
+        Assert.assertTrue(this.miCount == 0, "Event must not be called on Mi");
         Assert.assertTrue(this.mathCount > 0, "Event must be called on Math");
-        Assert.assertTrue(this.docCount > 0,
-                "Event must be called on Document");
+        Assert
+                .assertTrue(this.docCount > 0,
+                        "Event must be called on Document");
     }
 
     /**
