@@ -14,11 +14,13 @@
  * limitations under the License.
  */
 
-/* $Id: OperatorDictTest.java 887 2009-02-10 13:15:15Z maxberger $ */
+/* $Id: OperatorDictTest.java,v 51c390b5de9a 2009/09/07 14:34:58 max $ */
 
 package net.sourceforge.jeuclid.test;
 
 import net.sourceforge.jeuclid.elements.support.operatordict.OperatorDictionary;
+import net.sourceforge.jeuclid.elements.support.operatordict.OperatorDictionary2;
+import net.sourceforge.jeuclid.elements.support.operatordict.OperatorDictionary3;
 import net.sourceforge.jeuclid.elements.support.operatordict.UnknownAttributeException;
 
 import org.testng.Assert;
@@ -27,7 +29,7 @@ import org.testng.annotations.Test;
 /**
  * Tests the OperatorDict class.
  * 
- * @version $Revision: 887 $
+ * @version $Revision: 51c390b5de9a $
  */
 public class OperatorDictTest {
     /**
@@ -39,29 +41,66 @@ public class OperatorDictTest {
 
     /**
      * Test various operators for correct default values.
-     * @throws Exception if the test fails.
+     * 
+     * @throws Exception
+     *             if the test fails.
      */
     @Test
-    public void testAttrs() throws Exception {
-        final OperatorDictionary opDict = OperatorDictionary.getInstance();
-        Assert.assertEquals(opDict.getDefaultAttributeValue("\u002d",
-                "infix", "lspace"), "mediummathspace");
-        Assert.assertEquals(opDict.getDefaultAttributeValue("\u002d",
-                "prefix", "lspace"), "0em");
+    public void testAttrs2() throws Exception {
+        final OperatorDictionary opDict = OperatorDictionary2.getInstance();
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u002d", "infix",
+                "lspace"), "mediummathspace");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u002d", "prefix",
+                "lspace"), "0em");
         Assert.assertEquals(opDict.getDefaultAttributeValue("\u002d",
                 "postfix", "lspace"), "verythinmathspace");
-        Assert.assertEquals(opDict.getDefaultAttributeValue("\u0028",
-                "prefix", "lspace"), "0em");
-        Assert.assertEquals(opDict.getDefaultAttributeValue("\u0028",
-                "infix", "lspace"), "0em");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u0028", "prefix",
+                "lspace"), "0em");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u0028", "infix",
+                "lspace"), "0em");
         Assert.assertEquals(opDict.getDefaultAttributeValue("\u0028",
                 "postfix", "lspace"), "0em");
-        Assert.assertEquals(opDict.getDefaultAttributeValue("\u2063",
-                "infix", "rspace"), "0em");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u2063", "infix",
+                "rspace"), "0em");
         Assert.assertEquals(opDict.getDefaultAttributeValue("\u2063",
                 "postfix", "rspace"), "0em");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u2063", "infix",
+                "fence"), "false");
+        try {
+            opDict.getDefaultAttributeValue("\u2063", "infix", "foobar");
+            Assert.fail("foobar should throw UnknownAttributeException!");
+        } catch (final UnknownAttributeException uae) {
+            // Ignore
+        }
+    }
+
+    /**
+     * Test various operators for correct default values.
+     * 
+     * @throws Exception
+     *             if the test fails.
+     */
+    @Test
+    public void testAttrs3() throws Exception {
+        final OperatorDictionary opDict = OperatorDictionary3.getInstance();
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u002d", "infix",
+                "lspace"), "mediummathspace");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u002d", "prefix",
+                "lspace"), "mediummathspace");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u002d",
+                "postfix", "lspace"), "mediummathspace");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u0028", "prefix",
+                "lspace"), "0em");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u0028", "infix",
+                "lspace"), "0em");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u0028",
+                "postfix", "lspace"), "0em");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u2063", "infix",
+                "rspace"), "0em");
         Assert.assertEquals(opDict.getDefaultAttributeValue("\u2063",
-                "infix", "fence"), "false");
+                "postfix", "rspace"), "0em");
+        Assert.assertEquals(opDict.getDefaultAttributeValue("\u2063", "infix",
+                "fence"), "false");
         try {
             opDict.getDefaultAttributeValue("\u2063", "infix", "foobar");
             Assert.fail("foobar should throw UnknownAttributeException!");
